import click
from typing import Optional

from sdgs_tools.aplikasi_sdgs.excel import make_template_individu
from sdgs_tools.aplikasi_sdgs.excel import make_template_keluarga
from sdgs_tools.aplikasi_sdgs.export import export_individu as _export_individu
from sdgs_tools.aplikasi_sdgs.export import export_keluarga as _export_keluarga


@click.group("aplikasi")
def aplikasi():
    pass


@aplikasi.command("template-individu")
@click.argument("nama_file", type=click.Path(), default="Data INDIVIDU SDGS.xlsx")
def template_individu(nama_file: str):
    try:
        make_template_individu(filepath=nama_file)
        click.echo(f"Berhasil membuat template individu")
    except Exception as e:
        click.echo(f"Gagal membuat template individu karena {repr(e)}")


@aplikasi.command("template-keluarga")
@click.argument("nama_file", type=click.Path(), default="Data KELUARGA SDGS.xlsx")
def template_keluarga(nama_file: str):
    try:
        make_template_keluarga(filepath=nama_file)
        click.echo(f"Berhasil membuat template keluarga")
    except Exception as e:
        click.echo(f"Gagal membuat template keluarga karena {repr(e)}")


@aplikasi.command("export-individu")
@click.option("--ranges", type=str, help='Baris yang diambil datanya misal "2-100"')
@click.option(
    "--baris-penghasilan",
    type=int,
    default=2,
    help="Baris kosong pertama di sheet penghasilan",
)
@click.option("--individu/--no-individu", default=True)
@click.option("--pekerjaan/--no-pekerjaan", default=True)
@click.option("--pengasilan/--no-pengasilan", default=True)
@click.option("--kesehatan/--no-kesehatan", default=True)
@click.option("--disabilitas/--no-disabilitas", default=True)
@click.option("--pendidikan/--no-pendidikan", default=True)
@click.argument(
    "nama_file",
    type=click.Path(exists=True),
    default="Data INDIVIDU SDGS.xlsx",
)
def export_individu(
    nama_file: str,
    ranges: str = None,
    baris_penghasilan: int = 2,
    individu: bool = True,
    pekerjaan: bool = True,
    pengasilan: bool = True,
    kesehatan: bool = True,
    disabilitas: bool = True,
    pendidikan: bool = True,
):
    try:
        _export_individu(
            filepath=nama_file,
            ranges=ranges,
            row_penghasilan=baris_penghasilan,
            row_start=2,
            skip_individu=not individu,
            skip_pekerjaan=not pekerjaan,
            skip_pengasilan=not pengasilan,
            skip_kesehatan=not kesehatan,
            skip_disabilitas=not disabilitas,
            skip_pendidikan=not pendidikan,
        )
    except FileNotFoundError:
        click.echo("Gagal mengeksport data karena file template tidak ditemukan")
    except Exception as e:
        click.echo(f"Gagal mengeksport data individu karena {repr(e)}")


@aplikasi.command("export-keluarga")
@click.option(
    "--ranges", type=str, required=True, help='Baris yang diambil datanya misal "2-100"'
)
@click.option("--baris-pendidikan", type=int, default=2)
@click.option("--baris-kesehatan", type=int, default=2)
@click.option("--baris-tenaga_kesehatan", type=int, default=2)
@click.option("--baris-sarpras", type=int, default=2)
@click.option("--lokasi/--no-lokasi", default=True)
@click.option("--pendidikan/--no-pendidikan", default=True)
@click.option("--kesehatan/--no-kesehatan", default=True)
@click.option("--tenaga_kesehatan/--no-tenaga-kesehatan", default=True)
@click.option("--sarpras/--no-sarpras", default=True)
@click.option("--lain_lain/--no-lain-lain", default=True)
@click.argument(
    "nama_file",
    type=click.Path(exists=True),
    default="Data KELUARGA SDGS.xlsx",
)
def export_keluarga(
    nama_file: str,
    ranges: str,
    baris_pendidikan: int = 2,
    baris_kesehatan: int = 2,
    baris_tenaga_kesehatan: int = 2,
    baris_sarpras: int = 2,
    lokasi: bool = True,
    pendidikan: bool = True,
    kesehatan: bool = True,
    tenaga_kesehatan: bool = True,
    sarpras: bool = True,
    lain_lain: bool = True,
):
    try:
        _export_keluarga(
            filepath=nama_file,
            ranges=ranges,
            row_pendidikan=baris_pendidikan,
            row_kesehatan=baris_kesehatan,
            row_tenaga_kesehatan=baris_tenaga_kesehatan,
            row_sarpras=baris_sarpras,
            skip_lokasi=not lokasi,
            skip_pendidikan=not pendidikan,
            skip_kesehatan=not kesehatan,
            skip_tenaga_kesehatan=not tenaga_kesehatan,
            skip_sarpras=not sarpras,
            skip_lain_lain=not lain_lain,
        )
    except FileNotFoundError:
        click.echo("Gagal mengeksport data karena file template tidak ditemukan")
    except Exception as e:
        click.echo(f"Gagal mengeksport data keluarga karena {repr(e)}")



from uiautomator2 import Device, UiObject
from openpyxl.worksheet.worksheet import Worksheet

from sdgs_tools.aplikasi_sdgs.utils import d_get_text, menu_to, swipe_box


SARPRAS_COL = {
    "B": ("com.kemendes.survey:id/txtNIK", ""),
    # "C": ("com.kemendes.survey:id/txtNama", "Tujuan : Lokasi pekerjaan utama Jenis Transportasi : Darat"),
    # "D": ("com.kemendes.survey:id/txtAlamat", "Waktu Tempuh :0.25 jam, Biaya : 5000"),
    "G": ("com.kemendes.survey:id/txtTelpon", "Kemudahan :"),
    "H": ("com.kemendes.survey:id/txtStatus", ""),
}


def get_data_sarpras(d: Device, ws: Worksheet, no_kk: str, row: int):
    menu_to(d, "AKSES SARANA PRASARANA")
    box_daftar_sarpras: UiObject = d(resourceId="com.kemendes.survey:id/itemsSarana")
    survey_boxes: UiObject = box_daftar_sarpras.child(
        resourceId="com.kemendes.survey:id/box"
    )
    if survey_boxes.count == 0:
        return row
    for survey_box in survey_boxes:
        ws[f"A{row}"] = no_kk
        for col, (resourceId, lstrp) in SARPRAS_COL.items():
            current = survey_box.child(resourceId=resourceId)
            value: str = current.info.get("text")
            if isinstance(value, str):
                ws[f"{col}{row}"] = value.lstrip(lstrp)
        tujuan_jenis: str = survey_box.child(
            resourceId="com.kemendes.survey:id/txtNama"
        ).info.get("text")
        tujuan_jenis = tujuan_jenis.lstrip("Tujuan : ")
        tujuan_jenis = tujuan_jenis.replace(" Jenis Transportasi", "")
        tujuan, jenis = tujuan_jenis.split(":")
        ws[f"C{row}"] = tujuan.strip()
        ws[f"D{row}"] = jenis.strip()
        waktu_biaya: str = survey_box.child(
            resourceId="com.kemendes.survey:id/txtAlamat"
        ).info.get("text")
        waktu_biaya = waktu_biaya.lstrip("Waktu Tempuh :")
        waktu_biaya = waktu_biaya.replace(", Biaya", "")
        waktu, biaya = waktu_biaya.split(":")
        ws[f"E{row}"] = waktu.strip()
        ws[f"F{row}"] = biaya.strip()
        row += 1
        swipe_box(d, survey_box)
    d(className="android.widget.ScrollView").fling.vert.backward()
    return row



import click
import os
import sys

from sdgs_tools.ext.export import html_to_xlsx

LOGGING_FORMAT = "%(asctime)s - %(name)s - %(levelname)s - %(message)s"


@click.command("export")
@click.option("--offset", default=1, type=int, help="Mulai dari baris")
@click.argument(
    "filename",
    required=True,
    type=click.Path(exists=True, file_okay=True, dir_okay=False, resolve_path=True),
    default="DATA INDIVIDU.xls",
)
@click.argument(
    "outfile",
    type=click.Path(),
    default="DATA INDIVIDU-output.xlsx",
)
def exporter(offset: int, filename: str, outfile: str):
    if not outfile.endswith(".xlsx"):
        outfile += ".xlsx"
    if os.path.isfile(outfile):
        click.echo(f"File output {outfile} sudah ada, membatalkan.")
        sys.exit()
    click.echo(f"Mengeksport data dari {filename}")
    click.echo(f"Dari baris ke {offset}")
    click.echo(f"Menjadi {outfile}")
    html_to_xlsx(filename, outfile, offset)
    input("Selesai! Silahkan tutup jendela ini.")



import click

from sdgs_tools import __version__
from sdgs_tools.cli import aplikasi
from sdgs_tools.cli import exporter


@click.group("sdgs-tools")
def cli():
    pass


cli.add_command(aplikasi, "aplikasi")
cli.add_command(exporter, "exporter")


def main():
    click.echo(f"sdgs-tools v{__version__}")
    click.echo("Dibuat oleh Habib Rohman")
    click.echo("Error? pm https://t.me/hexatester")
    click.echo("Open donasi https://saweria.co/hexatester")
    cli()


if __name__ == "__main__":
    main()



from .lokasi import get_data_lokasi
from .pendidikan import get_data_pendidikan
from .kesehatan import get_data_kesehatan
from .tenaga_kesehatan import get_data_tenaga_kesehatan
from .sarpras import get_data_sarpras
from .lain_lain import get_data_lain_lain


__all__ = [
    "get_data_lokasi",
    "get_data_pendidikan",
    "get_data_kesehatan",
    "get_data_tenaga_kesehatan",
    "get_data_sarpras",
    "get_data_lain_lain",
]



import click
from openpyxl import load_workbook, Workbook
from uiautomator2 import Device

from sdgs_tools.aplikasi_sdgs.individu import (
    get_data_individu,
    get_data_pekerjaan,
    get_data_penghasilan,
    get_data_kesehatan,
    get_data_disabilitas,
    get_data_pendidikan,
)
from sdgs_tools.aplikasi_sdgs.utils import menu_to
from sdgs_tools.utils import parse_range


def export_individu(
    filepath: str,
    ranges: str = None,
    row_penghasilan: int = 2,
    row_start: int = 2,
    skip_individu: bool = False,
    skip_pekerjaan: bool = False,
    skip_pengasilan: bool = False,
    skip_kesehatan: bool = False,
    skip_disabilitas: bool = False,
    skip_pendidikan: bool = False,
):
    d = Device()
    wb = load_workbook(filepath)
    individu = wb["Individu"]

    def make_row(row: int, row_penghasilan: int):
        rt_rw = individu[f"A{row}"].value
        if not rt_rw:
            click.echo(
                f"Kolom rt/rw kosong di baris {row}, membatalkan operasi selanjutnya"
            )
            return False
        no_kk = individu[f"B{row}"].value
        if not no_kk:
            click.echo(f"Kolom nomor kk kosong di baris {row}, membatalkan operasi")
            return False
        nik: str = individu[f"C{row}"].value
        if not nik:
            click.echo(f"Kolom nik kosong di baris {row}, membatalkan operasi")
            return False
        # Input rt rw no_kk nik & Tampilkan
        form_rt_rw = d(resourceId="com.kemendes.survey:id/txtRTRW")
        form_rt_rw.send_keys(rt_rw)
        form_kk = d(resourceId="com.kemendes.survey:id/txtNoKK")
        form_kk.send_keys(no_kk)
        form_nik = d(resourceId="com.kemendes.survey:id/txtNIK")
        form_nik.send_keys(nik)
        d.press("back")
        d(resourceId="com.kemendes.survey:id/btnCariRT").click()
        menu_to(d, "DATA INDIVIDU")
        if not d(resourceId="com.kemendes.survey:id/txtNama").info.get("text"):
            click.echo(f"Lewati data kosong untuk rtrw {rt_rw} no kk {no_kk} nik {nik}")
            return False
        if not skip_individu:
            get_data_individu(d, individu, row)
        if not skip_pekerjaan:
            get_data_pekerjaan(d, individu, row)
        if not skip_kesehatan:
            get_data_kesehatan(d, individu, row)
        if not skip_disabilitas:
            get_data_disabilitas(d, individu, row)
        if not skip_pendidikan:
            get_data_pendidikan(d, individu, row)
        if not skip_pengasilan:
            row_penghasilan = get_data_penghasilan(
                d, wb["Penghasilan"], nik, row_penghasilan
            )
        click.echo(f"Eksport individu #{row} {nik} berhasil!")
        return True

    if ranges is None:
        success: bool = True
        while success:
            success = make_row(row_start, row_penghasilan)
            row_start += 1
    else:
        rows = parse_range(ranges)
        rows = list(set(rows))
        for row in rows:
            make_row(row, row_penghasilan)
    wb.save(filepath)



from uiautomator2 import Device
from openpyxl.worksheet.worksheet import Worksheet

from sdgs_tools.aplikasi_sdgs.utils import d_get_text, menu_to

# resourceId
DISABILITAS_COL = {
    # Disabilitas
    "BL": "com.kemendes.survey:id/cbTunanetra",
    "BM": "com.kemendes.survey:id/cbTunarungu",
    "BN": "com.kemendes.survey:id/cbTunawicara",
    "BO": "com.kemendes.survey:id/cbTunarungiwicara",
    "BP": "com.kemendes.survey:id/cbTunadaksa",
    "BQ": "com.kemendes.survey:id/cbTunagrahita",
    "BR": "com.kemendes.survey:id/cbTunalaras",
    "BS": "com.kemendes.survey:id/cbCacatKusta",
    "BT": "com.kemendes.survey:id/cbCacatGanda",
    "BU": "com.kemendes.survey:id/cbDipasung",
}


def get_data_disabilitas(d: Device, ws: Worksheet, row: int):
    menu_to(d, "DISABILITAS")
    for col, resourceId in DISABILITAS_COL.items():
        ws[f"{col}{row}"] = d_get_text(d, resourceId)
    d(className="android.widget.ScrollView").fling.vert.backward()



from openpyxl import Workbook

from .utils import set_ws_header

INDIVIDU = {
    "A": "RT/RW",
    "B": "Nomor KK",
    "C": "NIK",
    "D": "Nama",
    "E": "Jenis Kelamin",
    "F": "Tempat Lahir",
    "G": "Tgl Lahir",
    "H": "Usia",
    "I": "Status",
    "J": "Usia Menikah",
    "K": "Agama",
    "L": "Suku",
    "M": "Warga Negara",
    "N": "No HP",
    "O": "No WA",
    "P": "Email",
    "Q": "FB",
    "R": "Twitter",
    "S": "Instagram",
    "T": "Internet",
    "U": "Akses Internet Lewat",
    "V": "Kecepatan Internet",
    # Pekerjaan
    "W": "Kondisi Pekerjaan",
    "X": "Pekerjaan Utama",
    "Y": "Jaminan Sosial",
    "Z": "Penghasilan",
    # Kesehatan - Penyakit
    "AA": "Muntaber",
    "AB": "Demam Berdarah",
    "AC": "Campak",
    "AC": "Malaria",
    "AE": "Flu Burung",
    "AF": "Covid-19",
    "AG": "Hepatitis B",
    "AH": "Leptospirosis",
    "AI": "Kolera",
    "AJ": "Gizi Buruk",
    "AK": "Jantung",
    "AL": "TBC Paru",
    "AM": "Kanker",
    "AN": "Diabetes",
    "AO": "Hepatitis E",
    "AP": "Difteri",
    "AQ": "Chikungunya",
    "AR": "Lumpuh",
    "AS": "Lainnya",
    # Kesehatan - Fasilitas kesehatan
    "AT": "RS",
    "AU": "RS Bersalin",
    "AV": "Puskesmas Rawat Inap",
    "AW": "Puskesmas Tanpa Rawat Inap",
    "AX": "Puskesmas Pembantu",
    "AY": "Poliklinik",
    "AZ": "Praktik Dokter",
    "BA": "Rumah Bersalin",
    "BB": "Praktik Bidan",
    "BC": "Poskedes",
    "BC": "Polindes",
    "BE": "Apotik",
    "BF": "Toko Khusus",
    "BG": "Posyandu",
    "BH": "Posbindu",
    "BI": "Praktik Dukun",
    "BJ": "Jaminan Sosial Kesehatan",
    "BK": "Melahirkan",
    # Disabilitas
    "BL": "Buta",
    "BM": "Tuli",
    "BN": "Bisu",
    "BO": "Bisu-tuli",
    "BP": "Cacat tubuh",
    "BQ": "Cacat mental",
    "BR": "Eks-sakit jiwa",
    "BS": "Eks-sakit kusta",
    "BT": "Cacat ganda",
    "BU": "Dipasung",
    # Pendidikan
    "BV": "Pendidikan Tertinggi",
    "BW": "Tahun Pendidikan Dasar",
    "BX": "Bahasa",
    "BY": "Bahasa Lembaga",
    "BZ": "Kerja bakti",
    "CA": "Siskamling",
    "CB": "Pesta rakyat",
    "CC": "Menolong kematian",
    "CD": "Menolong sakit",
    "CE": "Menolong kecelakaan",
    "CF": "Pelayanan desa",
    "CG": "Masukan",
    "CH": "Bencana",
}

INDIVIDU_PENGHASILAN = {
    "A": "NIK",
    "B": "Sumber",
    "C": "Jumlah",
    "D": "Satuan",
    "E": "PenghasilanSetahun",
    "F": "Diekspor",
    "F": "Status",
}

KELUARGA = {
    "A": "RT/RW",
    "B": "Nomor KK",
    "C": "Nama",
    "D": "Alamat",
    "E": "No. HP",
    "F": "No. Telepon",
    "G": "NIK Kepala Keluarga",
    "H": "Status Tempat Tinggal",
    "I": "Status Lahan",
    "J": "Luas Lantai",
    "K": "Luas Tempat Tinggal",
    "L": "Jenis Lantai",
    "M": "Dinding",
    "N": "Jendela",
    "O": "Atap",
    "P": "Penerangan",
    "Q": "Memasak",
    "R": "Sampah",
    "S": "MCK",
    "T": "Air Mandi",
    "U": "Fasilitas BAB",
    "V": "Air Minum",
    "W": "Pembuangan Air Limbah",
    "X": "Dibawah SUTET",
    "Y": "Di bantaran sungai",
    "Z": "Di lereng gunung / bukit",
    "AA": "Kondisi Rumah",
    # Lain lain
    "AB": "Jumlah Anggota Keluarga Menggunakan Transportasi Umum",
    "AC": "Jumlah Anggota Keluarga Menggunakan Transportasi Umum bulan sebelum",
    "AD": "BLT",
    "AE": "PKH",
    "AF": "BST",
    "AG": "Banpres",
    "AH": "UMKM",
    "AI": "Bantuan Pekerja",
    "AJ": "Pendidikan Anak",
    "AK": "Ban Lainnya",
    "AL": "Rata-rata Pengeluaran",
}

KELUARGA_PENDIDIKAN = {
    "A": "Nomor KK",
    "B": "Fasilitas",
    "C": "Jarak Tempuh",
    "D": "Waktu Tempuh",
    "E": "Kemudahan",
    "F": "Keterangan",
}

KELUARGA_KESEHATAN = {
    "A": "Nomor KK",
    "B": "Fasilitas",
    "C": "Jarak Tempuh",
    "D": "Waktu Tempuh",
    "E": "Kemudahan",
    "F": "Keterangan",
}

KELUARGA_TENAGA_KESEHATAN = {
    "A": "Nomor KK",
    "B": "Fasilitas",
    "C": "Jarak Tempuh",
    "D": "Waktu Tempuh",
    "E": "Kemudahan",
    "F": "Keterangan",
}

KELUARGA_SARPRAS = {
    "A": "Nomor KK",
    "B": "Tujuan",
    "C": "Jenis Transportasi",
    "D": "Transportasi Umum",
    "E": "Waktu Tempuh",
    "F": "Biaya",
    "G": "Kemudahan",
    "H": "Keterangan",
}


def add_header_individu(wb: Workbook, row: int = 1):
    set_ws_header(wb.create_sheet("Individu"), INDIVIDU, row)
    set_ws_header(wb.create_sheet("Penghasilan"), INDIVIDU_PENGHASILAN, row)


def add_header_keluarga(wb: Workbook, row: int):
    set_ws_header(wb.create_sheet("Keluarga"), KELUARGA, row)
    set_ws_header(wb.create_sheet("Pendidikan"), KELUARGA_PENDIDIKAN, row)
    set_ws_header(wb.create_sheet("Kesehatan"), KELUARGA_KESEHATAN, row)
    set_ws_header(wb.create_sheet("Tenaga Kesehatan"), KELUARGA_TENAGA_KESEHATAN, row)
    set_ws_header(wb.create_sheet("Sarpras"), KELUARGA_SARPRAS, row)


def make_template_individu(filepath: str = "Data INDIVIDU SDGS.xlsx", row: int = 1):
    if not filepath.endswith(".xlsx"):
        filepath += ".xlsx"
    wb = Workbook()
    add_header_individu(wb, row)
    wb.save(filepath)


def make_template_keluarga(filepath: str = "Data KELUARGA SDGS.xlsx", row: int = 1):
    if not filepath.endswith(".xlsx"):
        filepath += ".xlsx"
    wb = Workbook()
    add_header_keluarga(wb, row)
    wb.save(filepath)



from uiautomator2 import Device
from openpyxl.worksheet.worksheet import Worksheet

from sdgs_tools.aplikasi_sdgs.utils import d_get_text, menu_to

LAIN_LAIN_COL = {
    "AB": "com.kemendes.survey:id/txtTransportUmumSebulanTerakhir",
    "AC": "com.kemendes.survey:id/txtTranportUmumSebelumnya",
    "AD": "com.kemendes.survey:id/cbBLT",
    "AE": "com.kemendes.survey:id/cbPKH",
    "AF": "com.kemendes.survey:id/cbBST",
    "AG": "com.kemendes.survey:id/cbBanpres",
    "AH": "com.kemendes.survey:id/cbUMKM",
    "AI": "com.kemendes.survey:id/cbBantuanPekerja",
    "AJ": "com.kemendes.survey:id/cbBantuanPendidikan",
    "AK": "com.kemendes.survey:id/cbBantuanLainnya",
    "AL": "com.kemendes.survey:id/txtPengeluaranRata2",
}


def get_data_lain_lain(d: Device, ws: Worksheet, row: int):
    menu_to(d, "LAIN-LAIN")
    for col, resourceId in LAIN_LAIN_COL.items():
        ws[f"{col}{row}"] = d_get_text(d, resourceId)
    d(className="android.widget.ScrollView").fling.vert.backward()



import click
import logging
from bs4 import BeautifulSoup, Tag
from dateutil.parser import parse as date_parse
from openpyxl import Workbook
from openpyxl.worksheet.worksheet import Worksheet
from typing import List, Tuple

logger = logging.getLogger(__name__)


def add_header(ws: Worksheet):
    ws["A1"] = "ID"
    ws["B1"] = "Provinsi"
    ws["C1"] = "Kabupaten"
    ws["D1"] = "Kecamatan"
    ws["E1"] = "Desa"
    ws["F1"] = "RT"
    ws["G1"] = "Rw"
    ws["H1"] = "No KK"
    ws["I1"] = "NIK"
    ws["J1"] = "Nama"
    ws["K1"] = "Jenis Kelamin"
    ws["L1"] = "Tgl Lahir"
    ws["M1"] = "Tempat Lahir"
    ws["N1"] = "Usia"
    ws["O1"] = "Status"
    ws["P1"] = "Usia Saat Nikah"
    ws["Q1"] = "Agama"
    ws["R1"] = "Suku Bangsa"
    ws["S1"] = "Warga Negara"
    ws["T1"] = "No HP"
    ws["U1"] = "No WA"
    ws["V1"] = "Email"
    ws["W1"] = "Facebook"
    ws["X1"] = "Instagram"
    ws["Y1"] = "Twitter"
    ws["Z1"] = "Aktif Internet"
    ws["AA1"] = "Akses Internet"
    ws["AB1"] = "Kecepatan Internet"
    ws["AC1"] = "User ID"
    ws["AD1"] = "Tgl Entri"
    ws["AE1"] = "Ter Upload"


def rt_rw(data: str) -> Tuple[str, str]:
    data = data.strip("\xa0")
    if "/" in data:
        data = data.replace("0", "")
        return tuple(data.split("/"))  # type: ignore
    if " " in data:
        data = data.replace("0", "")
        return tuple(data.split(" "))  # type: ignore
    if len(data) == 3 and "0" in data:
        return tuple(data.split("0"))  # type: ignore
    elif len(data) == 4 and data.count("0") == 2:
        res = data.split("0")
        if len(res) == 3:
            return (res[1], res[2])
    return data, ""


def add_row(ws: Worksheet, tds: List[Tag], row: int = 2):
    nik: str = tds[7].get_text()
    nama: str = tds[8].get_text()
    logger.debug(f"Menambahkan data {nik}/{nama}")
    ws[f"A{row}"] = tds[0].get_text()
    ws[f"B{row}"] = tds[1].get_text()
    ws[f"C{row}"] = tds[2].get_text()
    ws[f"D{row}"] = tds[3].get_text()
    ws[f"E{row}"] = tds[4].get_text()
    ws[f"F{row}"], ws[f"G{row}"] = rt_rw(tds[5].get_text())
    ws[f"H{row}"] = tds[6].get_text()
    ws[f"I{row}"] = nik
    ws[f"J{row}"] = nama
    ws[f"K{row}"] = tds[9].get_text()
    ws[f"L{row}"] = date_parse(tds[10].get_text()).date()
    ws[f"M{row}"] = tds[11].get_text()
    ws[f"N{row}"] = tds[12].get_text()
    ws[f"O{row}"] = tds[13].get_text()
    ws[f"P{row}"] = tds[14].get_text()
    ws[f"Q{row}"] = tds[15].get_text()
    ws[f"R{row}"] = tds[16].get_text()
    ws[f"S{row}"] = tds[17].get_text()
    ws[f"T{row}"] = tds[18].get_text()
    ws[f"U{row}"] = tds[19].get_text()
    ws[f"V{row}"] = tds[20].get_text()
    ws[f"W{row}"] = tds[21].get_text()
    ws[f"X{row}"] = tds[22].get_text()
    ws[f"Y{row}"] = tds[23].get_text()
    ws[f"Z{row}"] = tds[24].get_text()
    ws[f"AA{row}"] = tds[25].get_text()
    ws[f"AB{row}"] = tds[26].get_text()
    ws[f"AC{row}"] = tds[27].get_text()
    ws[f"AD{row}"] = tds[28].get_text()
    ws[f"AE{row}"] = tds[29].get_text()


def html_to_xlsx(source: str, destination: str, offset: int = 1):
    try:
        with open(source, "r") as sumber:
            soup = BeautifulSoup(sumber.read(), "html.parser")
    except Exception as e:
        click.echo(f"Gagal membuka file {source} karena {e}")
    try:
        table: Tag = soup.find("table")
        data: List[Tag] = table.find_all("tr")
        data = data[offset:]
    except Exception as e:
        click.echo(
            "Format file tidak valid, silahkan download ulang dari api sdgs "
            "atau hubungi pengembang (https://t.me/hexatester)"
        )
    wb = Workbook()
    ws = wb.active
    add_header(ws)
    for index, row in enumerate(data):
        try:
            add_row(ws, row.find_all("td"), index + offset + 1)
        except Exception as e:
            click.echo(f"Gagal menambahkan data baris ke {index+1}, karena {e}")
    try:
        wb.save(destination)
    except Exception as e:
        click.echo(f"Gagal menyimpan file karena {e}")
    else:
        click.echo(f"Berhasil mengeksport data sebanyak {len(data)}")



from uiautomator2 import Device
from openpyxl.worksheet.worksheet import Worksheet

from sdgs_tools.aplikasi_sdgs.utils import d_get_text, menu_to

# resourceId
PENDIDIKAN_COL = {
    "BV": "com.kemendes.survey:id/cbPendidikanTertinggi",
    "BW": "com.kemendes.survey:id/txtTahunPendidikanDasar",
    "BX": "com.kemendes.survey:id/txtBahasa",
    "BY": "com.kemendes.survey:id/txtBahasaLembaga",
    "BZ": "com.kemendes.survey:id/txtKerjaBakti",
    "CA": "com.kemendes.survey:id/txtSiskamling",
    "CB": "com.kemendes.survey:id/txtPestaRakyat",
    "CC": "com.kemendes.survey:id/txtMenolongKematian",
    "CD": "com.kemendes.survey:id/txtMenolongSakit",
    "CE": "com.kemendes.survey:id/txtMenolongKecelakaan",
    "CF": "com.kemendes.survey:id/cbPerolehPelayananDesa",
    "CG": "com.kemendes.survey:id/cbMasukan",
    "CH": "com.kemendes.survey:id/cbBencana",
}


def get_data_pendidikan(d: Device, ws: Worksheet, row: int):
    menu_to(d, "PENDIDIKAN")
    d(text="PENDIDIKAN").click()
    for col, resourceId in PENDIDIKAN_COL.items():
        ws[f"{col}{row}"] = d_get_text(d, resourceId)
    d(className="android.widget.ScrollView").fling.vert.backward()



from .individu import get_data_individu
from .pekerjaan import get_data_pekerjaan
from .penghasilan import get_data_penghasilan
from .kesehatan import get_data_kesehatan
from .disabilitas import get_data_disabilitas
from .pendidikan import get_data_pendidikan


__all__ = [
    "get_data_individu",
    "get_data_pekerjaan",
    "get_data_penghasilan",
    "get_data_kesehatan",
    "get_data_disabilitas",
    "get_data_pendidikan",
]



from openpyxl import Workbook
from openpyxl.worksheet.worksheet import Worksheet
from uiautomator2 import Device, UiObject

from sdgs_tools.aplikasi_sdgs.utils import d_get_text, menu_to

# PER BOX! resourceId
PENGHASILAN_COL = {
    # "A": "NIK",
    "B": "com.kemendes.survey:id/txtSumber",
    "C": "com.kemendes.survey:id/txtJumlah",
    "D": "com.kemendes.survey:id/txtSatuan",
    "E": "com.kemendes.survey:id/txtPenghasilanSetahun",
    "F": "com.kemendes.survey:id/txtDiekspor",
    "G": "com.kemendes.survey:id/txtStatus",
}


def get_data_penghasilan(d: Device, ws: Worksheet, nik: str, row: int):
    menu_to(d, "PENGHASILAN")
    # d(text="PENGHASILAN").click()
    box_daftar_penghasilan = d(resourceId="com.kemendes.survey:id/itemsPenghasilan")
    survey_box: UiObject = box_daftar_penghasilan.child(
        resourceId="com.kemendes.survey:id/box"
    )
    if survey_box.count == 0:
        return row
    for box_penghasilan in survey_box:
        ws[f"A{row}"] = nik
        # Sumber penghasilan
        box_content = box_penghasilan.child(
            resourceId="com.kemendes.survey:id/txtSumber"
        )
        if box_content.exists:
            ws[f"B{row}"] = box_content.info.get("text")
        # Jumlah
        box_content = box_penghasilan.child(
            resourceId="com.kemendes.survey:id/txtJumlah"
        )
        if box_content.exists:
            ws[f"C{row}"] = box_content.info.get("text")
        # Satuan
        box_content = box_penghasilan.child(
            resourceId="com.kemendes.survey:id/txtSatuan"
        )
        if box_content.exists:
            ws[f"D{row}"] = box_content.info.get("text")
        # Penghasilan Setahun
        box_content = box_penghasilan.child(
            resourceId="com.kemendes.survey:id/txtPenghasilanSetahun"
        )
        if box_content.exists:
            value: str = box_content.info.get("text")
            ws[f"E{row}"] = value.lstrip("Penghasilan setahun : ")
        # Diekspor
        box_content = box_penghasilan.child(
            resourceId="com.kemendes.survey:id/txtDiekspor"
        )
        if box_content.exists:
            value = box_content.info.get("text")
            ws[f"F{row}"] = value.lstrip("Ekspor : ")
        # Status
        box_content = box_penghasilan.child(
            resourceId="com.kemendes.survey:id/txtStatus"
        )
        if box_content.exists:
            ws[f"G{row}"] = box_content.info.get("text")
        row += 1
    d(className="android.widget.ScrollView").fling.vert.backward()
    return row



from uiautomator2 import Device, UiObject
from openpyxl.worksheet.worksheet import Worksheet
from typing import Optional

from sdgs_tools.aplikasi_sdgs.utils import d_get_text, menu_to


# resourceId
KESEHATAN_COL = {
    # Kesehatan - Penyakit
    "AA": "com.kemendes.survey:id/cbMuntaber",
    "AB": "com.kemendes.survey:id/cbDemamBerdarah",
    "AC": "com.kemendes.survey:id/cbCampak",
    "AC": "com.kemendes.survey:id/cbMalaria",
    "AE": "com.kemendes.survey:id/cbFlueBurung",
    "AF": "com.kemendes.survey:id/cbCovid19",
    "AG": "com.kemendes.survey:id/cbHepatisis",
    "AH": "com.kemendes.survey:id/cbLeptospirosis",
    "AI": "com.kemendes.survey:id/cbKolera",
    "AJ": "com.kemendes.survey:id/cbGiziburuk",
    "AK": "com.kemendes.survey:id/cbJantung",
    "AL": "com.kemendes.survey:id/cbTBC",
    "AM": "com.kemendes.survey:id/cbKanker",
    "AN": "com.kemendes.survey:id/cbDiabetes",
    "AO": "com.kemendes.survey:id/cbHepatisisE",
    "AP": "com.kemendes.survey:id/cbDifteri",
    "AQ": "com.kemendes.survey:id/cbChikungunya",
    "AR": "com.kemendes.survey:id/cbLumpuh",
    "AS": "com.kemendes.survey:id/cbLainnya",
    # Kesehatan - Fasilitas kesehatan
    "AT": "com.kemendes.survey:id/txtRS",
    "AU": "com.kemendes.survey:id/txtRSBersalin",
    "AV": "com.kemendes.survey:id/txtPuskesmasRawatInap",
    "AW": "com.kemendes.survey:id/txtPuskesmasTanpaRawatInap",
    "AX": "com.kemendes.survey:id/txtPuskesmasPembantu",
    "AY": "com.kemendes.survey:id/txtPoliklinik",
    "AZ": "com.kemendes.survey:id/txtPraktikDokter",
    "BA": "com.kemendes.survey:id/txtRumahBersalin",
    "BB": "com.kemendes.survey:id/txtPraktikBidan",
    "BC": "com.kemendes.survey:id/txtPoskedes",
    "BD": "com.kemendes.survey:id/txtPolindes",
    "BE": "com.kemendes.survey:id/txtApotik",
    "BF": "com.kemendes.survey:id/txtTokoKhusus",
    "BG": "com.kemendes.survey:id/txtPosyandu",
    "BH": "com.kemendes.survey:id/txtPosbindu",
    "BI": "com.kemendes.survey:id/txtPraktikDukun",
    "BJ": "com.kemendes.survey:id/cbJaminanKesehatanIndividu",
    "BK": "com.kemendes.survey:id/cbMelahirkan",
}


def get_data_kesehatan(d: Device, ws: Worksheet, row: int):
    menu_to(d, "KESEHATAN")
    # d(text="KESEHATAN").click()
    for col, resourceId in KESEHATAN_COL.items():
        value = d_get_text(d, resourceId)
        if value != "Jumlah":
            ws[f"{col}{row}"] = value
    d(className="android.widget.ScrollView").fling.vert.backward()



import click
from openpyxl import load_workbook, Workbook
from uiautomator2 import Device

from sdgs_tools.aplikasi_sdgs.keluarga import (
    get_data_lokasi,
    get_data_pendidikan,
    get_data_kesehatan,
    get_data_tenaga_kesehatan,
    get_data_sarpras,
    get_data_lain_lain,
)
from sdgs_tools.aplikasi_sdgs.utils import menu_to
from sdgs_tools.utils import parse_range


def export_keluarga(
    filepath: str,
    ranges: str,
    row_pendidikan: int = 2,
    row_kesehatan: int = 2,
    row_tenaga_kesehatan: int = 2,
    row_sarpras: int = 2,
    skip_lokasi: bool = False,
    skip_pendidikan: bool = False,
    skip_kesehatan: bool = False,
    skip_tenaga_kesehatan: bool = False,
    skip_sarpras: bool = False,
    skip_lain_lain: bool = False,
):
    d = Device()
    wb = load_workbook(filepath)
    keluarga = wb["Keluarga"]
    rows = parse_range(ranges)

    for row in rows:
        rt_rw = keluarga[f"A{row}"].value
        if not rt_rw:
            click.echo(
                f"Kolom rt/rw kosong di baris {row}, membatalkan operasi selanjutnya"
            )
            return False
        no_kk = keluarga[f"B{row}"].value
        if not no_kk:
            click.echo(f"Kolom nomor kk kosong di baris {row}, membatalkan operasi")
            return False
        form_rt_rw = d(resourceId="com.kemendes.survey:id/txtRTRW")
        form_rt_rw.send_keys(rt_rw)
        form_kk = d(resourceId="com.kemendes.survey:id/txtNoKK")
        form_kk.send_keys(no_kk)
        d.press("back")
        d(resourceId="com.kemendes.survey:id/btnCariRT").click()
        menu_to(d, "LOKASI & PEMUKIMAN")
        d(className="android.widget.ScrollView").fling.vert.backward()
        if not d(resourceId="com.kemendes.survey:id/txtNama").info.get("text"):
            click.echo(f"Lewati data kosong untuk rtrw {rt_rw} no kk {no_kk}")
            return False
        if not skip_lokasi:
            get_data_lokasi(d, keluarga, row)
        if not skip_pendidikan:
            row_pendidikan = get_data_pendidikan(
                d,
                wb["Pendidikan"],
                no_kk,
                row_pendidikan,
            )
            row_pendidikan += 1
        if not skip_kesehatan:
            row_kesehatan = get_data_kesehatan(
                d,
                wb["Kesehatan"],
                no_kk,
                row_kesehatan,
            )
            row_kesehatan += 1
        if not skip_tenaga_kesehatan:
            row_tenaga_kesehatan = get_data_tenaga_kesehatan(
                d,
                wb["Tenaga Kesehatan"],
                no_kk,
                row_tenaga_kesehatan,
            )
            row_tenaga_kesehatan += 1
        if not skip_sarpras:
            row_sarpras = get_data_sarpras(
                d,
                wb["Sarpras"],
                no_kk,
                row_sarpras,
            )
            row_sarpras += 1
        if not skip_lain_lain:
            get_data_lain_lain(d, keluarga, row)
        click.echo(f"Berhasil export data no kk {no_kk}")

    wb.save(filepath)



from uiautomator2 import Device, UiObjectNotFoundError
from openpyxl.worksheet.worksheet import Worksheet

from sdgs_tools.aplikasi_sdgs.utils import d_get_text, menu_to

INDIVIDU_COL = {
    "D": "com.kemendes.survey:id/txtNama",
    "E": "com.kemendes.survey:id/cbJenisKelamin",
    "F": "com.kemendes.survey:id/txtTempatLahir",
    "G": "com.kemendes.survey:id/txtTglLahir",
    "H": "com.kemendes.survey:id/txtUsia",
    "I": "com.kemendes.survey:id/cbStatus",
    "J": "com.kemendes.survey:id/txtUsiaSaatNikah",
    "K": "com.kemendes.survey:id/cbAgama",
    "L": "com.kemendes.survey:id/txtSuku",
    "M": "com.kemendes.survey:id/cbWargaNegara",
    "N": "com.kemendes.survey:id/txtNoHP",
    "O": "com.kemendes.survey:id/txtNoWA",
    "P": "com.kemendes.survey:id/txtEmail",
    "Q": "com.kemendes.survey:id/txtFB",
    "R": "com.kemendes.survey:id/txtTwitter",
    "S": "com.kemendes.survey:id/txtInstagram",
    "T": "com.kemendes.survey:id/cbInternet",
    # "U": "com.kemendes.survey:id/cbAksesInternetLewat",
    # "V": "com.kemendes.survey:id/cbKecepatanInternet",
}


def get_data_individu(d: Device, ws: Worksheet, row: int):
    menu_to(d, "DATA INDIVIDU")
    # d(text="DATA INDIVIDU").click()
    for col, resourceId in INDIVIDU_COL.items():
        cell = f"{col}{row}"
        try:
            ws[cell] = d_get_text(d, resourceId)
        except UiObjectNotFoundError:
            continue
    if ws[f"T{row}"].value == "Ya":
        # Internet = Ya
        ws[f"U{row}"] = d_get_text(d, "com.kemendes.survey:id/cbAksesInternetLewat")
        ws[f"V{row}"] = d_get_text(d, "com.kemendes.survey:id/cbKecepatanInternet")
    d(className="android.widget.ScrollView").fling.vert.backward()



from uiautomator2 import Device, UiObject
from openpyxl.worksheet.worksheet import Worksheet

from sdgs_tools.aplikasi_sdgs.utils import d_get_text, menu_to, swipe_box

KESEHATAN_COL = {
    "B": ("com.kemendes.survey:id/txtNIK", ""),
    "C": ("com.kemendes.survey:id/txtNama", "Jarak : "),
    "D": ("com.kemendes.survey:id/txtAlamat", "Waktu Tempuh :"),
    "E": ("com.kemendes.survey:id/txtTelpon", "Kemudahan :"),
    "F": ("com.kemendes.survey:id/txtStatus", ""),
}


def get_data_kesehatan(d: Device, ws: Worksheet, no_kk: str, row: int):
    menu_to(d, "AKSES KESEHATAN")
    box_daftar_kesehatan: UiObject = d(
        resourceId="com.kemendes.survey:id/itemsKesehatan"
    )
    survey_boxes: UiObject = box_daftar_kesehatan.child(
        resourceId="com.kemendes.survey:id/box"
    )
    if survey_boxes.count == 0:
        return row
    for survey_box in survey_boxes:
        ws[f"A{row}"] = no_kk
        for col, (resourceId, lstrp) in KESEHATAN_COL.items():
            current = survey_box.child(resourceId=resourceId)
            value: str = current.info.get("text")
            if isinstance(value, str):
                ws[f"{col}{row}"] = value.lstrip(lstrp)
        row += 1
        swipe_box(d, survey_box)
    d(className="android.widget.ScrollView").fling.vert.backward()
    return row



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['sdgs_tools',
 'sdgs_tools.aplikasi_sdgs',
 'sdgs_tools.aplikasi_sdgs.export',
 'sdgs_tools.aplikasi_sdgs.individu',
 'sdgs_tools.aplikasi_sdgs.keluarga',
 'sdgs_tools.cli',
 'sdgs_tools.ext']

package_data = \
{'': ['*']}

install_requires = \
['beautifulsoup4>=4.9.3,<5.0.0',
 'click>=8.0.1,<9.0.0',
 'openpyxl>=3.0.7,<4.0.0',
 'python-dateutil>=2.8.1,<3.0.0',
 'uiautomator2>=2.16.7,<3.0.0']

entry_points = \
{'console_scripts': ['sdgs-tools = sdgs_tools.__main__:main']}

setup_kwargs = {
    'name': 'sdgs-tools',
    'version': '0.4.0',
    'description': '',
    'long_description': '# sdgs-tools\n\n[![sdgs-tools - PyPi](https://img.shields.io/pypi/v/sdgs-tools)](https://pypi.org/project/sdgs-tools/)\n[![Supported Python versions](https://img.shields.io/pypi/pyversions/sdgs-tools)](https://pypi.org/project/sdgs-tools/)\n[![Donate Saweria](https://img.shields.io/badge/Donasi-Saweria-blue)](https://saweria.co/hexatester)\n[![LISENSI](https://img.shields.io/github/license/hexatester/sdgs-tools)](https://github.com/hexatester/sdgs-tools/blob/main/LICENSE)\n\nAlat bantu sdgs-desa kemendesa.\n\n## Legal / Hukum\n\nKode ini sama sekali tidak berafiliasi dengan, diizinkan, dipelihara, disponsori atau didukung oleh [Kemendesa](https://kemendesa.go.id/) atau afiliasi atau anak organisasinya. Ini adalah perangkat lunak yang independen dan tidak resmi. _Gunakan dengan risiko Anda sendiri._\n',
    'author': 'hexatester',
    'author_email': 'hexatester@protonmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/hexatester/sdgs-dashboard',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7.10,<4.0.0',
}


setup(**setup_kwargs)



from uiautomator2 import Device
from openpyxl.worksheet.worksheet import Worksheet

from sdgs_tools.aplikasi_sdgs.utils import d_get_text, menu_to

# EXCEL COL : d(resourceId="{}")
PEKERJAAN_COL = {
    "W": "com.kemendes.survey:id/cbKondisiPekerjaan",
    "X": "com.kemendes.survey:id/cbPekerjaanUtama",
    "Y": "com.kemendes.survey:id/cbJaminanSosial",
    "Z": "com.kemendes.survey:id/txtPenghasilan",
}


def get_data_pekerjaan(d: Device, ws: Worksheet, row: int):
    menu_to(d, "PEKERJAAN")
    # d(text="PEKERJAAN").click()
    for col, resourceId in PEKERJAAN_COL.items():
        ws[f"{col}{row}"] = d_get_text(d, resourceId)
    d(className="android.widget.ScrollView").fling.vert.backward()



from uiautomator2 import Device
from openpyxl.worksheet.worksheet import Worksheet

from sdgs_tools.aplikasi_sdgs.utils import d_get_text, menu_to

KELUARGA_COL = {
    "C": "com.kemendes.survey:id/txtNama",
    "D": "com.kemendes.survey:id/txtAlamat",
    "E": "com.kemendes.survey:id/txtHP",
    "F": "com.kemendes.survey:id/txtNoTelpon",
    "G": "com.kemendes.survey:id/txtNIKKepalaKeluarga",
    "H": "com.kemendes.survey:id/cbTempatTinggal",
    "I": "com.kemendes.survey:id/cbStatusLahan",
    "J": "com.kemendes.survey:id/txtLuasLantaiTempatTinggal",
    "K": "com.kemendes.survey:id/txtLuasLahanTempatTinggal",
    "L": "com.kemendes.survey:id/cbJenisLantai",
    "M": "com.kemendes.survey:id/cbDinding",
    "N": "com.kemendes.survey:id/cbJendela",
    "O": "com.kemendes.survey:id/cbAtap",
    "P": "com.kemendes.survey:id/cbPenerangan",
    "Q": "com.kemendes.survey:id/cbEnergiMemasak",
    "R": "com.kemendes.survey:id/cbTempatPembuangan",
    "S": "com.kemendes.survey:id/cbFasilitasMCK",
    "T": "com.kemendes.survey:id/cbSumberAirMandi",
    "U": "com.kemendes.survey:id/cbFasilitasBuangAir",
    "V": "com.kemendes.survey:id/cbSumberAirMinum",
    "W": "com.kemendes.survey:id/cbTempatPembuanganLimbah",
    "X": "com.kemendes.survey:id/cbSUTET",
    "Y": "com.kemendes.survey:id/cbBantaranSungai",
    "Z": "com.kemendes.survey:id/cbRumahDiLereng",
    "AA": "com.kemendes.survey:id/cbKondisiRumah",
}


def get_data_lokasi(d: Device, ws: Worksheet, row: int):
    menu_to(d, "LOKASI & PEMUKIMAN")
    for col, resourceId in KELUARGA_COL.items():
        ws[f"{col}{row}"] = d_get_text(d, resourceId)
    d(className="android.widget.ScrollView").fling.vert.backward()
